require 'cuke_parser'
require 'fileutils'
require 'rspec'

module CukeParserTest

	class ReportTest

		include RSpec::Matchers

		def initialize
			@utils = CukeParser::ReportEngine::ReporterUtils.new
			location = "./builds/2013-04-23_03-01-25/archive"
			@cuke = CukeParser.json(location)
			#we need to overwrite the date because get_json_build just grabs Time.now as the date
			@cuke.date = "2013-04-23"
			@cuke.time = "03-01-25"
			@options = {:title => "Rick Suite",:output_dir => "Rick Suite",:json_file => "./builds/2013-04-23_03-01-25/archive/cucumber.json"}
		end
	
		def test_utils
			test_model_status_display
			test_time_to_words
			test_find_cuke_metrics
			test_get_scenario_metrics
			test_get_step_metrics
		end
		
		def test_reporter
			test_generate_report
		end
		
		def test_generate_report
			#delete any existing directory to be safe
			FileUtils.rm_rf(Dir[@options[:output_dir]]) if Dir.exists?(@options[:output_dir])
			CukeParser.generate_report(@cuke,@options)
			#don't want to check to make sure files are the same as they are html files and are likely to change often as I update CSS/JS, etc.
			File.exists?("Rick Suite/2013_04_23_03_01_25/cucumber.json").should be_true
			File.exists?("Rick Suite/2013_04_23_03_01_25/home_page.html").should be_true
			File.exists?("Rick Suite/2013_04_23_03_01_25/features/Rick Test.html ").should be_true
		end
		
		def test_model_status_display
			{:class => "skipped"}.eql?(@utils.model_status_display("skipped")).should be_true
			{:class => "failed"}.eql?(@utils.model_status_display("failed")).should be_true
			{:class => "passed"}.eql?(@utils.model_status_display("passed")).should be_true
		end
		
		def test_time_to_words
			"01 hours and 23 mins and 20 secs and 000 ms".eql?(@utils.time_to_words(5000000000000)).should be_true
			"16 mins and 40 secs and 000 ms".eql?(@utils.time_to_words(1000000000000)).should be_true
			"50 secs and 000 ms".eql?(@utils.time_to_words(50000000000)).should be_true
			"211 ms".eql?(@utils.time_to_words(211021000)).should be_true
		end
		
		def test_get_scenario_metrics
			scenario_metrics = {:feature_metrics=>{:scenario_count=>1, :passed=>1, :failed=>0}, :scenario_metrics=>{:step_count=>7, :passed=>7, :failed=>0, :skipped=>0}}
			scenario_metrics.eql?(@utils.get_scenario_metrics(@cuke.features.first)).should be_true
		end
		
		def test_get_step_metrics
			step_metrics = {:step_count=>7, :passed=>7, :failed=>0, :skipped=>0}
			step_metrics.eql?(@utils.get_scenario_metrics(@cuke.features.first)[:scenario_metrics]).should be_true
		end
		
		def test_find_cuke_metrics
			cuke_metrics = {:scenarios_passed_total=>1, :scenarios_failed_total=>0, :steps_passed_total=>7, :steps_failed_total=>0, :steps_skipped_total=>0,
											:"Rick Test"=>{:feature_metrics=>{:scenario_count=>1, :passed=>1, :failed=>0}, :scenario_metrics=>{:step_count=>7, :passed=>7, :failed=>0, :skipped=>0}}}
			cuke_metrics.eql?(@utils.find_cuke_metrics(@cuke)).should be_true
		end
		
		
		
		def test_json
			location = "./builds/2013-04-23_03-01-25/archive"
			result = CukeParser.json(location)
			#we need to overwrite the date because get_json_build just grabs Time.now as the date
			result.date = "2013-04-23"
			result.time = "03-01-25"
			#write our results to a text file
			output = File.open("result.txt","w+")
			CukeParser.write_build(result,output)
			output.close
			FileUtils.compare_file("result.txt","./results/json_results.txt").should be_true
		end
	end

end